# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilitySimulationJobDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'test_id': 'str',
        'scope': 'str',
        'status': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'started_at': 'datetime',
        'completed_at': 'datetime',
        'total_targets': 'int',
        'total_planned_sends': 'int',
        'next_send_index': 'int',
        'sent_count': 'int',
        'success_count': 'int',
        'failure_count': 'int',
        'progress_percent': 'float',
        'active_target_label': 'str',
        'estimated_remaining_ms': 'int',
        'config_snapshot': 'DeliverabilitySimulationJobConfigDto',
        'error_summary': 'DeliverabilitySimulationJobErrorSummaryDto'
    }

    attribute_map = {
        'id': 'id',
        'test_id': 'testId',
        'scope': 'scope',
        'status': 'status',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'started_at': 'startedAt',
        'completed_at': 'completedAt',
        'total_targets': 'totalTargets',
        'total_planned_sends': 'totalPlannedSends',
        'next_send_index': 'nextSendIndex',
        'sent_count': 'sentCount',
        'success_count': 'successCount',
        'failure_count': 'failureCount',
        'progress_percent': 'progressPercent',
        'active_target_label': 'activeTargetLabel',
        'estimated_remaining_ms': 'estimatedRemainingMs',
        'config_snapshot': 'configSnapshot',
        'error_summary': 'errorSummary'
    }

    def __init__(self, id=None, test_id=None, scope=None, status=None, created_at=None, updated_at=None, started_at=None, completed_at=None, total_targets=None, total_planned_sends=None, next_send_index=None, sent_count=None, success_count=None, failure_count=None, progress_percent=None, active_target_label=None, estimated_remaining_ms=None, config_snapshot=None, error_summary=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilitySimulationJobDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._test_id = None
        self._scope = None
        self._status = None
        self._created_at = None
        self._updated_at = None
        self._started_at = None
        self._completed_at = None
        self._total_targets = None
        self._total_planned_sends = None
        self._next_send_index = None
        self._sent_count = None
        self._success_count = None
        self._failure_count = None
        self._progress_percent = None
        self._active_target_label = None
        self._estimated_remaining_ms = None
        self._config_snapshot = None
        self._error_summary = None
        self.discriminator = None

        self.id = id
        self.test_id = test_id
        self.scope = scope
        self.status = status
        self.created_at = created_at
        self.updated_at = updated_at
        self.started_at = started_at
        self.completed_at = completed_at
        self.total_targets = total_targets
        self.total_planned_sends = total_planned_sends
        self.next_send_index = next_send_index
        self.sent_count = sent_count
        self.success_count = success_count
        self.failure_count = failure_count
        self.progress_percent = progress_percent
        self.active_target_label = active_target_label
        self.estimated_remaining_ms = estimated_remaining_ms
        self.config_snapshot = config_snapshot
        self.error_summary = error_summary

    @property
    def id(self):
        """Gets the id of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The id of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeliverabilitySimulationJobDto.


        :param id: The id of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def test_id(self):
        """Gets the test_id of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The test_id of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: str
        """
        return self._test_id

    @test_id.setter
    def test_id(self, test_id):
        """Sets the test_id of this DeliverabilitySimulationJobDto.


        :param test_id: The test_id of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and test_id is None:  # noqa: E501
            raise ValueError("Invalid value for `test_id`, must not be `None`")  # noqa: E501

        self._test_id = test_id

    @property
    def scope(self):
        """Gets the scope of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The scope of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this DeliverabilitySimulationJobDto.


        :param scope: The scope of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and scope is None:  # noqa: E501
            raise ValueError("Invalid value for `scope`, must not be `None`")  # noqa: E501
        allowed_values = ["INBOX", "PHONE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and scope not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `scope` ({0}), must be one of {1}"  # noqa: E501
                .format(scope, allowed_values)
            )

        self._scope = scope

    @property
    def status(self):
        """Gets the status of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The status of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DeliverabilitySimulationJobDto.


        :param status: The status of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["RUNNING", "PAUSED", "CANCELLED", "COMPLETED", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def created_at(self):
        """Gets the created_at of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The created_at of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DeliverabilitySimulationJobDto.


        :param created_at: The created_at of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The updated_at of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DeliverabilitySimulationJobDto.


        :param updated_at: The updated_at of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def started_at(self):
        """Gets the started_at of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The started_at of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this DeliverabilitySimulationJobDto.


        :param started_at: The started_at of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: datetime
        """

        self._started_at = started_at

    @property
    def completed_at(self):
        """Gets the completed_at of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The completed_at of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: datetime
        """
        return self._completed_at

    @completed_at.setter
    def completed_at(self, completed_at):
        """Sets the completed_at of this DeliverabilitySimulationJobDto.


        :param completed_at: The completed_at of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: datetime
        """

        self._completed_at = completed_at

    @property
    def total_targets(self):
        """Gets the total_targets of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The total_targets of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: int
        """
        return self._total_targets

    @total_targets.setter
    def total_targets(self, total_targets):
        """Sets the total_targets of this DeliverabilitySimulationJobDto.


        :param total_targets: The total_targets of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_targets is None:  # noqa: E501
            raise ValueError("Invalid value for `total_targets`, must not be `None`")  # noqa: E501

        self._total_targets = total_targets

    @property
    def total_planned_sends(self):
        """Gets the total_planned_sends of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The total_planned_sends of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: int
        """
        return self._total_planned_sends

    @total_planned_sends.setter
    def total_planned_sends(self, total_planned_sends):
        """Sets the total_planned_sends of this DeliverabilitySimulationJobDto.


        :param total_planned_sends: The total_planned_sends of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_planned_sends is None:  # noqa: E501
            raise ValueError("Invalid value for `total_planned_sends`, must not be `None`")  # noqa: E501

        self._total_planned_sends = total_planned_sends

    @property
    def next_send_index(self):
        """Gets the next_send_index of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The next_send_index of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: int
        """
        return self._next_send_index

    @next_send_index.setter
    def next_send_index(self, next_send_index):
        """Sets the next_send_index of this DeliverabilitySimulationJobDto.


        :param next_send_index: The next_send_index of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and next_send_index is None:  # noqa: E501
            raise ValueError("Invalid value for `next_send_index`, must not be `None`")  # noqa: E501

        self._next_send_index = next_send_index

    @property
    def sent_count(self):
        """Gets the sent_count of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The sent_count of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: int
        """
        return self._sent_count

    @sent_count.setter
    def sent_count(self, sent_count):
        """Sets the sent_count of this DeliverabilitySimulationJobDto.


        :param sent_count: The sent_count of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and sent_count is None:  # noqa: E501
            raise ValueError("Invalid value for `sent_count`, must not be `None`")  # noqa: E501

        self._sent_count = sent_count

    @property
    def success_count(self):
        """Gets the success_count of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The success_count of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: int
        """
        return self._success_count

    @success_count.setter
    def success_count(self, success_count):
        """Sets the success_count of this DeliverabilitySimulationJobDto.


        :param success_count: The success_count of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and success_count is None:  # noqa: E501
            raise ValueError("Invalid value for `success_count`, must not be `None`")  # noqa: E501

        self._success_count = success_count

    @property
    def failure_count(self):
        """Gets the failure_count of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The failure_count of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: int
        """
        return self._failure_count

    @failure_count.setter
    def failure_count(self, failure_count):
        """Sets the failure_count of this DeliverabilitySimulationJobDto.


        :param failure_count: The failure_count of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failure_count is None:  # noqa: E501
            raise ValueError("Invalid value for `failure_count`, must not be `None`")  # noqa: E501

        self._failure_count = failure_count

    @property
    def progress_percent(self):
        """Gets the progress_percent of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The progress_percent of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: float
        """
        return self._progress_percent

    @progress_percent.setter
    def progress_percent(self, progress_percent):
        """Sets the progress_percent of this DeliverabilitySimulationJobDto.


        :param progress_percent: The progress_percent of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and progress_percent is None:  # noqa: E501
            raise ValueError("Invalid value for `progress_percent`, must not be `None`")  # noqa: E501

        self._progress_percent = progress_percent

    @property
    def active_target_label(self):
        """Gets the active_target_label of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The active_target_label of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: str
        """
        return self._active_target_label

    @active_target_label.setter
    def active_target_label(self, active_target_label):
        """Sets the active_target_label of this DeliverabilitySimulationJobDto.


        :param active_target_label: The active_target_label of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: str
        """

        self._active_target_label = active_target_label

    @property
    def estimated_remaining_ms(self):
        """Gets the estimated_remaining_ms of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The estimated_remaining_ms of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: int
        """
        return self._estimated_remaining_ms

    @estimated_remaining_ms.setter
    def estimated_remaining_ms(self, estimated_remaining_ms):
        """Sets the estimated_remaining_ms of this DeliverabilitySimulationJobDto.


        :param estimated_remaining_ms: The estimated_remaining_ms of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: int
        """

        self._estimated_remaining_ms = estimated_remaining_ms

    @property
    def config_snapshot(self):
        """Gets the config_snapshot of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The config_snapshot of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: DeliverabilitySimulationJobConfigDto
        """
        return self._config_snapshot

    @config_snapshot.setter
    def config_snapshot(self, config_snapshot):
        """Sets the config_snapshot of this DeliverabilitySimulationJobDto.


        :param config_snapshot: The config_snapshot of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: DeliverabilitySimulationJobConfigDto
        """
        if self.local_vars_configuration.client_side_validation and config_snapshot is None:  # noqa: E501
            raise ValueError("Invalid value for `config_snapshot`, must not be `None`")  # noqa: E501

        self._config_snapshot = config_snapshot

    @property
    def error_summary(self):
        """Gets the error_summary of this DeliverabilitySimulationJobDto.  # noqa: E501


        :return: The error_summary of this DeliverabilitySimulationJobDto.  # noqa: E501
        :rtype: DeliverabilitySimulationJobErrorSummaryDto
        """
        return self._error_summary

    @error_summary.setter
    def error_summary(self, error_summary):
        """Sets the error_summary of this DeliverabilitySimulationJobDto.


        :param error_summary: The error_summary of this DeliverabilitySimulationJobDto.  # noqa: E501
        :type: DeliverabilitySimulationJobErrorSummaryDto
        """
        if self.local_vars_configuration.client_side_validation and error_summary is None:  # noqa: E501
            raise ValueError("Invalid value for `error_summary`, must not be `None`")  # noqa: E501

        self._error_summary = error_summary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilitySimulationJobDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilitySimulationJobDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AITransformCreateOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'conditions': 'list[str]',
        'instructions': 'list[str]',
        'output_schema': 'StructuredOutputSchema',
        'output_schema_id': 'str',
        'extract_prompt': 'str'
    }

    attribute_map = {
        'name': 'name',
        'conditions': 'conditions',
        'instructions': 'instructions',
        'output_schema': 'outputSchema',
        'output_schema_id': 'outputSchemaId',
        'extract_prompt': 'extractPrompt'
    }

    def __init__(self, name=None, conditions=None, instructions=None, output_schema=None, output_schema_id=None, extract_prompt=None, local_vars_configuration=None):  # noqa: E501
        """AITransformCreateOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._conditions = None
        self._instructions = None
        self._output_schema = None
        self._output_schema_id = None
        self._extract_prompt = None
        self.discriminator = None

        self.name = name
        self.conditions = conditions
        self.instructions = instructions
        self.output_schema = output_schema
        self.output_schema_id = output_schema_id
        self.extract_prompt = extract_prompt

    @property
    def name(self):
        """Gets the name of this AITransformCreateOptions.  # noqa: E501


        :return: The name of this AITransformCreateOptions.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AITransformCreateOptions.


        :param name: The name of this AITransformCreateOptions.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def conditions(self):
        """Gets the conditions of this AITransformCreateOptions.  # noqa: E501


        :return: The conditions of this AITransformCreateOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this AITransformCreateOptions.


        :param conditions: The conditions of this AITransformCreateOptions.  # noqa: E501
        :type: list[str]
        """

        self._conditions = conditions

    @property
    def instructions(self):
        """Gets the instructions of this AITransformCreateOptions.  # noqa: E501


        :return: The instructions of this AITransformCreateOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._instructions

    @instructions.setter
    def instructions(self, instructions):
        """Sets the instructions of this AITransformCreateOptions.


        :param instructions: The instructions of this AITransformCreateOptions.  # noqa: E501
        :type: list[str]
        """

        self._instructions = instructions

    @property
    def output_schema(self):
        """Gets the output_schema of this AITransformCreateOptions.  # noqa: E501


        :return: The output_schema of this AITransformCreateOptions.  # noqa: E501
        :rtype: StructuredOutputSchema
        """
        return self._output_schema

    @output_schema.setter
    def output_schema(self, output_schema):
        """Sets the output_schema of this AITransformCreateOptions.


        :param output_schema: The output_schema of this AITransformCreateOptions.  # noqa: E501
        :type: StructuredOutputSchema
        """

        self._output_schema = output_schema

    @property
    def output_schema_id(self):
        """Gets the output_schema_id of this AITransformCreateOptions.  # noqa: E501


        :return: The output_schema_id of this AITransformCreateOptions.  # noqa: E501
        :rtype: str
        """
        return self._output_schema_id

    @output_schema_id.setter
    def output_schema_id(self, output_schema_id):
        """Sets the output_schema_id of this AITransformCreateOptions.


        :param output_schema_id: The output_schema_id of this AITransformCreateOptions.  # noqa: E501
        :type: str
        """

        self._output_schema_id = output_schema_id

    @property
    def extract_prompt(self):
        """Gets the extract_prompt of this AITransformCreateOptions.  # noqa: E501


        :return: The extract_prompt of this AITransformCreateOptions.  # noqa: E501
        :rtype: str
        """
        return self._extract_prompt

    @extract_prompt.setter
    def extract_prompt(self, extract_prompt):
        """Sets the extract_prompt of this AITransformCreateOptions.


        :param extract_prompt: The extract_prompt of this AITransformCreateOptions.  # noqa: E501
        :type: str
        """

        self._extract_prompt = extract_prompt

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AITransformCreateOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AITransformCreateOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AnalyzeEmailHeadersResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'summary': 'EmailHeaderAnalysisSummary',
        'received_path': 'list[EmailHeaderReceivedHop]',
        'parsed_headers': 'dict(str, list[str])',
        'warnings': 'list[str]',
        'errors': 'list[str]'
    }

    attribute_map = {
        'summary': 'summary',
        'received_path': 'receivedPath',
        'parsed_headers': 'parsedHeaders',
        'warnings': 'warnings',
        'errors': 'errors'
    }

    def __init__(self, summary=None, received_path=None, parsed_headers=None, warnings=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """AnalyzeEmailHeadersResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._summary = None
        self._received_path = None
        self._parsed_headers = None
        self._warnings = None
        self._errors = None
        self.discriminator = None

        self.summary = summary
        self.received_path = received_path
        self.parsed_headers = parsed_headers
        self.warnings = warnings
        self.errors = errors

    @property
    def summary(self):
        """Gets the summary of this AnalyzeEmailHeadersResults.  # noqa: E501


        :return: The summary of this AnalyzeEmailHeadersResults.  # noqa: E501
        :rtype: EmailHeaderAnalysisSummary
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this AnalyzeEmailHeadersResults.


        :param summary: The summary of this AnalyzeEmailHeadersResults.  # noqa: E501
        :type: EmailHeaderAnalysisSummary
        """
        if self.local_vars_configuration.client_side_validation and summary is None:  # noqa: E501
            raise ValueError("Invalid value for `summary`, must not be `None`")  # noqa: E501

        self._summary = summary

    @property
    def received_path(self):
        """Gets the received_path of this AnalyzeEmailHeadersResults.  # noqa: E501


        :return: The received_path of this AnalyzeEmailHeadersResults.  # noqa: E501
        :rtype: list[EmailHeaderReceivedHop]
        """
        return self._received_path

    @received_path.setter
    def received_path(self, received_path):
        """Sets the received_path of this AnalyzeEmailHeadersResults.


        :param received_path: The received_path of this AnalyzeEmailHeadersResults.  # noqa: E501
        :type: list[EmailHeaderReceivedHop]
        """
        if self.local_vars_configuration.client_side_validation and received_path is None:  # noqa: E501
            raise ValueError("Invalid value for `received_path`, must not be `None`")  # noqa: E501

        self._received_path = received_path

    @property
    def parsed_headers(self):
        """Gets the parsed_headers of this AnalyzeEmailHeadersResults.  # noqa: E501


        :return: The parsed_headers of this AnalyzeEmailHeadersResults.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._parsed_headers

    @parsed_headers.setter
    def parsed_headers(self, parsed_headers):
        """Sets the parsed_headers of this AnalyzeEmailHeadersResults.


        :param parsed_headers: The parsed_headers of this AnalyzeEmailHeadersResults.  # noqa: E501
        :type: dict(str, list[str])
        """
        if self.local_vars_configuration.client_side_validation and parsed_headers is None:  # noqa: E501
            raise ValueError("Invalid value for `parsed_headers`, must not be `None`")  # noqa: E501

        self._parsed_headers = parsed_headers

    @property
    def warnings(self):
        """Gets the warnings of this AnalyzeEmailHeadersResults.  # noqa: E501


        :return: The warnings of this AnalyzeEmailHeadersResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this AnalyzeEmailHeadersResults.


        :param warnings: The warnings of this AnalyzeEmailHeadersResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this AnalyzeEmailHeadersResults.  # noqa: E501


        :return: The errors of this AnalyzeEmailHeadersResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this AnalyzeEmailHeadersResults.


        :param errors: The errors of this AnalyzeEmailHeadersResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyzeEmailHeadersResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AnalyzeEmailHeadersResults):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class GuestPortalDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'domain_id': 'str',
        'user_id': 'str',
        'name': 'str',
        'description': 'str',
        'link_help': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'login_url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'domain_id': 'domainId',
        'user_id': 'userId',
        'name': 'name',
        'description': 'description',
        'link_help': 'linkHelp',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'login_url': 'loginUrl'
    }

    def __init__(self, id=None, domain_id=None, user_id=None, name=None, description=None, link_help=None, created_at=None, updated_at=None, login_url=None, local_vars_configuration=None):  # noqa: E501
        """GuestPortalDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._domain_id = None
        self._user_id = None
        self._name = None
        self._description = None
        self._link_help = None
        self._created_at = None
        self._updated_at = None
        self._login_url = None
        self.discriminator = None

        self.id = id
        if domain_id is not None:
            self.domain_id = domain_id
        self.user_id = user_id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if link_help is not None:
            self.link_help = link_help
        self.created_at = created_at
        self.updated_at = updated_at
        self.login_url = login_url

    @property
    def id(self):
        """Gets the id of this GuestPortalDto.  # noqa: E501


        :return: The id of this GuestPortalDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GuestPortalDto.


        :param id: The id of this GuestPortalDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def domain_id(self):
        """Gets the domain_id of this GuestPortalDto.  # noqa: E501


        :return: The domain_id of this GuestPortalDto.  # noqa: E501
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this GuestPortalDto.


        :param domain_id: The domain_id of this GuestPortalDto.  # noqa: E501
        :type: str
        """

        self._domain_id = domain_id

    @property
    def user_id(self):
        """Gets the user_id of this GuestPortalDto.  # noqa: E501


        :return: The user_id of this GuestPortalDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this GuestPortalDto.


        :param user_id: The user_id of this GuestPortalDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def name(self):
        """Gets the name of this GuestPortalDto.  # noqa: E501


        :return: The name of this GuestPortalDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GuestPortalDto.


        :param name: The name of this GuestPortalDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this GuestPortalDto.  # noqa: E501


        :return: The description of this GuestPortalDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this GuestPortalDto.


        :param description: The description of this GuestPortalDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def link_help(self):
        """Gets the link_help of this GuestPortalDto.  # noqa: E501


        :return: The link_help of this GuestPortalDto.  # noqa: E501
        :rtype: str
        """
        return self._link_help

    @link_help.setter
    def link_help(self, link_help):
        """Sets the link_help of this GuestPortalDto.


        :param link_help: The link_help of this GuestPortalDto.  # noqa: E501
        :type: str
        """

        self._link_help = link_help

    @property
    def created_at(self):
        """Gets the created_at of this GuestPortalDto.  # noqa: E501


        :return: The created_at of this GuestPortalDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this GuestPortalDto.


        :param created_at: The created_at of this GuestPortalDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this GuestPortalDto.  # noqa: E501


        :return: The updated_at of this GuestPortalDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this GuestPortalDto.


        :param updated_at: The updated_at of this GuestPortalDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def login_url(self):
        """Gets the login_url of this GuestPortalDto.  # noqa: E501


        :return: The login_url of this GuestPortalDto.  # noqa: E501
        :rtype: str
        """
        return self._login_url

    @login_url.setter
    def login_url(self, login_url):
        """Sets the login_url of this GuestPortalDto.


        :param login_url: The login_url of this GuestPortalDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and login_url is None:  # noqa: E501
            raise ValueError("Invalid value for `login_url`, must not be `None`")  # noqa: E501

        self._login_url = login_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GuestPortalDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GuestPortalDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CheckEmailBlacklistOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain': 'str',
        'ip_address': 'str',
        'mx_host': 'str',
        'captcha_token': 'str'
    }

    attribute_map = {
        'domain': 'domain',
        'ip_address': 'ipAddress',
        'mx_host': 'mxHost',
        'captcha_token': 'captchaToken'
    }

    def __init__(self, domain=None, ip_address=None, mx_host=None, captcha_token=None, local_vars_configuration=None):  # noqa: E501
        """CheckEmailBlacklistOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain = None
        self._ip_address = None
        self._mx_host = None
        self._captcha_token = None
        self.discriminator = None

        self.domain = domain
        self.ip_address = ip_address
        self.mx_host = mx_host
        self.captcha_token = captcha_token

    @property
    def domain(self):
        """Gets the domain of this CheckEmailBlacklistOptions.  # noqa: E501

        Domain to expand into A and MX host IPv4 addresses  # noqa: E501

        :return: The domain of this CheckEmailBlacklistOptions.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this CheckEmailBlacklistOptions.

        Domain to expand into A and MX host IPv4 addresses  # noqa: E501

        :param domain: The domain of this CheckEmailBlacklistOptions.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def ip_address(self):
        """Gets the ip_address of this CheckEmailBlacklistOptions.  # noqa: E501

        Specific IPv4 address to check directly  # noqa: E501

        :return: The ip_address of this CheckEmailBlacklistOptions.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this CheckEmailBlacklistOptions.

        Specific IPv4 address to check directly  # noqa: E501

        :param ip_address: The ip_address of this CheckEmailBlacklistOptions.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def mx_host(self):
        """Gets the mx_host of this CheckEmailBlacklistOptions.  # noqa: E501

        Specific MX host to resolve and check directly  # noqa: E501

        :return: The mx_host of this CheckEmailBlacklistOptions.  # noqa: E501
        :rtype: str
        """
        return self._mx_host

    @mx_host.setter
    def mx_host(self, mx_host):
        """Sets the mx_host of this CheckEmailBlacklistOptions.

        Specific MX host to resolve and check directly  # noqa: E501

        :param mx_host: The mx_host of this CheckEmailBlacklistOptions.  # noqa: E501
        :type: str
        """

        self._mx_host = mx_host

    @property
    def captcha_token(self):
        """Gets the captcha_token of this CheckEmailBlacklistOptions.  # noqa: E501


        :return: The captcha_token of this CheckEmailBlacklistOptions.  # noqa: E501
        :rtype: str
        """
        return self._captcha_token

    @captcha_token.setter
    def captcha_token(self, captcha_token):
        """Sets the captcha_token of this CheckEmailBlacklistOptions.


        :param captcha_token: The captcha_token of this CheckEmailBlacklistOptions.  # noqa: E501
        :type: str
        """

        self._captcha_token = captcha_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckEmailBlacklistOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckEmailBlacklistOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.domain_monitor_controller_api import DomainMonitorControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestDomainMonitorControllerApi(unittest.TestCase):
    """DomainMonitorControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.domain_monitor_controller_api.DomainMonitorControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_compare_domain_monitor_runs(self):
        """Test case for compare_domain_monitor_runs

        Compare two monitor runs  # noqa: E501
        """
        pass

    def test_create_domain_monitor(self):
        """Test case for create_domain_monitor

        Create domain monitor  # noqa: E501
        """
        pass

    def test_create_domain_monitor_alert_sink(self):
        """Test case for create_domain_monitor_alert_sink

        Create alert sink for monitor  # noqa: E501
        """
        pass

    def test_delete_domain_monitor(self):
        """Test case for delete_domain_monitor

        Delete domain monitor  # noqa: E501
        """
        pass

    def test_delete_domain_monitor_alert_sink(self):
        """Test case for delete_domain_monitor_alert_sink

        Delete monitor alert sink  # noqa: E501
        """
        pass

    def test_get_domain_monitor(self):
        """Test case for get_domain_monitor

        Get domain monitor  # noqa: E501
        """
        pass

    def test_get_domain_monitor_alert_sinks(self):
        """Test case for get_domain_monitor_alert_sinks

        List alert sinks for monitor  # noqa: E501
        """
        pass

    def test_get_domain_monitor_auth_stack(self):
        """Test case for get_domain_monitor_auth_stack

        Get current auth stack for monitor domain  # noqa: E501
        """
        pass

    def test_get_domain_monitor_insights(self):
        """Test case for get_domain_monitor_insights

        Get monitor insights  # noqa: E501
        """
        pass

    def test_get_domain_monitor_run(self):
        """Test case for get_domain_monitor_run

        Get monitor run  # noqa: E501
        """
        pass

    def test_get_domain_monitor_runs(self):
        """Test case for get_domain_monitor_runs

        List monitor runs  # noqa: E501
        """
        pass

    def test_get_domain_monitor_series(self):
        """Test case for get_domain_monitor_series

        Get monitor trend series  # noqa: E501
        """
        pass

    def test_get_domain_monitor_summary(self):
        """Test case for get_domain_monitor_summary

        Get domain monitor summary  # noqa: E501
        """
        pass

    def test_get_domain_monitors(self):
        """Test case for get_domain_monitors

        List domain monitors  # noqa: E501
        """
        pass

    def test_run_domain_monitor_now(self):
        """Test case for run_domain_monitor_now

        Run monitor now  # noqa: E501
        """
        pass

    def test_run_due_domain_monitors(self):
        """Test case for run_due_domain_monitors

        Run due monitors for user  # noqa: E501
        """
        pass

    def test_update_domain_monitor(self):
        """Test case for update_domain_monitor

        Update domain monitor  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class SearchEmailsOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'inbox_ids': 'list[str]',
        'page_index': 'int',
        'page_size': 'int',
        'sort_direction': 'str',
        'unread_only': 'bool',
        'search_filter': 'str',
        'since': 'datetime',
        'before': 'datetime'
    }

    attribute_map = {
        'inbox_ids': 'inboxIds',
        'page_index': 'pageIndex',
        'page_size': 'pageSize',
        'sort_direction': 'sortDirection',
        'unread_only': 'unreadOnly',
        'search_filter': 'searchFilter',
        'since': 'since',
        'before': 'before'
    }

    def __init__(self, inbox_ids=None, page_index=None, page_size=None, sort_direction=None, unread_only=None, search_filter=None, since=None, before=None, local_vars_configuration=None):  # noqa: E501
        """SearchEmailsOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._inbox_ids = None
        self._page_index = None
        self._page_size = None
        self._sort_direction = None
        self._unread_only = None
        self._search_filter = None
        self._since = None
        self._before = None
        self.discriminator = None

        if inbox_ids is not None:
            self.inbox_ids = inbox_ids
        if page_index is not None:
            self.page_index = page_index
        if page_size is not None:
            self.page_size = page_size
        if sort_direction is not None:
            self.sort_direction = sort_direction
        if unread_only is not None:
            self.unread_only = unread_only
        if search_filter is not None:
            self.search_filter = search_filter
        if since is not None:
            self.since = since
        if before is not None:
            self.before = before

    @property
    def inbox_ids(self):
        """Gets the inbox_ids of this SearchEmailsOptions.  # noqa: E501

        Optional inbox ids to filter by. Can be repeated. By default will use all inboxes belonging to your account.  # noqa: E501

        :return: The inbox_ids of this SearchEmailsOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._inbox_ids

    @inbox_ids.setter
    def inbox_ids(self, inbox_ids):
        """Sets the inbox_ids of this SearchEmailsOptions.

        Optional inbox ids to filter by. Can be repeated. By default will use all inboxes belonging to your account.  # noqa: E501

        :param inbox_ids: The inbox_ids of this SearchEmailsOptions.  # noqa: E501
        :type: list[str]
        """

        self._inbox_ids = inbox_ids

    @property
    def page_index(self):
        """Gets the page_index of this SearchEmailsOptions.  # noqa: E501

        Optional page index in email list pagination  # noqa: E501

        :return: The page_index of this SearchEmailsOptions.  # noqa: E501
        :rtype: int
        """
        return self._page_index

    @page_index.setter
    def page_index(self, page_index):
        """Sets the page_index of this SearchEmailsOptions.

        Optional page index in email list pagination  # noqa: E501

        :param page_index: The page_index of this SearchEmailsOptions.  # noqa: E501
        :type: int
        """

        self._page_index = page_index

    @property
    def page_size(self):
        """Gets the page_size of this SearchEmailsOptions.  # noqa: E501

        Optional page size in email list pagination. Maximum size is 100. Use page index and sort to page through larger results  # noqa: E501

        :return: The page_size of this SearchEmailsOptions.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this SearchEmailsOptions.

        Optional page size in email list pagination. Maximum size is 100. Use page index and sort to page through larger results  # noqa: E501

        :param page_size: The page_size of this SearchEmailsOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                page_size is not None and page_size > 100):  # noqa: E501
            raise ValueError("Invalid value for `page_size`, must be a value less than or equal to `100`")  # noqa: E501

        self._page_size = page_size

    @property
    def sort_direction(self):
        """Gets the sort_direction of this SearchEmailsOptions.  # noqa: E501

        Optional createdAt sort direction ASC or DESC  # noqa: E501

        :return: The sort_direction of this SearchEmailsOptions.  # noqa: E501
        :rtype: str
        """
        return self._sort_direction

    @sort_direction.setter
    def sort_direction(self, sort_direction):
        """Sets the sort_direction of this SearchEmailsOptions.

        Optional createdAt sort direction ASC or DESC  # noqa: E501

        :param sort_direction: The sort_direction of this SearchEmailsOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["ASC", "DESC"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and sort_direction not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `sort_direction` ({0}), must be one of {1}"  # noqa: E501
                .format(sort_direction, allowed_values)
            )

        self._sort_direction = sort_direction

    @property
    def unread_only(self):
        """Gets the unread_only of this SearchEmailsOptions.  # noqa: E501

        Optional filter for unread emails only. All emails are considered unread until they are viewed in the dashboard or requested directly  # noqa: E501

        :return: The unread_only of this SearchEmailsOptions.  # noqa: E501
        :rtype: bool
        """
        return self._unread_only

    @unread_only.setter
    def unread_only(self, unread_only):
        """Sets the unread_only of this SearchEmailsOptions.

        Optional filter for unread emails only. All emails are considered unread until they are viewed in the dashboard or requested directly  # noqa: E501

        :param unread_only: The unread_only of this SearchEmailsOptions.  # noqa: E501
        :type: bool
        """

        self._unread_only = unread_only

    @property
    def search_filter(self):
        """Gets the search_filter of this SearchEmailsOptions.  # noqa: E501

        Optional search filter. Searches email recipients, sender, subject, email address and ID. Does not search email body  # noqa: E501

        :return: The search_filter of this SearchEmailsOptions.  # noqa: E501
        :rtype: str
        """
        return self._search_filter

    @search_filter.setter
    def search_filter(self, search_filter):
        """Sets the search_filter of this SearchEmailsOptions.

        Optional search filter. Searches email recipients, sender, subject, email address and ID. Does not search email body  # noqa: E501

        :param search_filter: The search_filter of this SearchEmailsOptions.  # noqa: E501
        :type: str
        """

        self._search_filter = search_filter

    @property
    def since(self):
        """Gets the since of this SearchEmailsOptions.  # noqa: E501

        Optional filter emails received after given date time  # noqa: E501

        :return: The since of this SearchEmailsOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this SearchEmailsOptions.

        Optional filter emails received after given date time  # noqa: E501

        :param since: The since of this SearchEmailsOptions.  # noqa: E501
        :type: datetime
        """

        self._since = since

    @property
    def before(self):
        """Gets the before of this SearchEmailsOptions.  # noqa: E501

        Optional filter emails received before given date time  # noqa: E501

        :return: The before of this SearchEmailsOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this SearchEmailsOptions.

        Optional filter emails received before given date time  # noqa: E501

        :param before: The before of this SearchEmailsOptions.  # noqa: E501
        :type: datetime
        """

        self._before = before

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchEmailsOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchEmailsOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class TotpDeviceDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'username': 'str',
        'issuer': 'str',
        'digits': 'int',
        'period': 'int',
        'algorithm': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'username': 'username',
        'issuer': 'issuer',
        'digits': 'digits',
        'period': 'period',
        'algorithm': 'algorithm',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, name=None, username=None, issuer=None, digits=None, period=None, algorithm=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """TotpDeviceDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._username = None
        self._issuer = None
        self._digits = None
        self._period = None
        self._algorithm = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.username = username
        self.issuer = issuer
        self.digits = digits
        self.period = period
        self.algorithm = algorithm
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this TotpDeviceDto.  # noqa: E501


        :return: The id of this TotpDeviceDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TotpDeviceDto.


        :param id: The id of this TotpDeviceDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this TotpDeviceDto.  # noqa: E501


        :return: The name of this TotpDeviceDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TotpDeviceDto.


        :param name: The name of this TotpDeviceDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def username(self):
        """Gets the username of this TotpDeviceDto.  # noqa: E501


        :return: The username of this TotpDeviceDto.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this TotpDeviceDto.


        :param username: The username of this TotpDeviceDto.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def issuer(self):
        """Gets the issuer of this TotpDeviceDto.  # noqa: E501


        :return: The issuer of this TotpDeviceDto.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this TotpDeviceDto.


        :param issuer: The issuer of this TotpDeviceDto.  # noqa: E501
        :type: str
        """

        self._issuer = issuer

    @property
    def digits(self):
        """Gets the digits of this TotpDeviceDto.  # noqa: E501


        :return: The digits of this TotpDeviceDto.  # noqa: E501
        :rtype: int
        """
        return self._digits

    @digits.setter
    def digits(self, digits):
        """Sets the digits of this TotpDeviceDto.


        :param digits: The digits of this TotpDeviceDto.  # noqa: E501
        :type: int
        """

        self._digits = digits

    @property
    def period(self):
        """Gets the period of this TotpDeviceDto.  # noqa: E501


        :return: The period of this TotpDeviceDto.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this TotpDeviceDto.


        :param period: The period of this TotpDeviceDto.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def algorithm(self):
        """Gets the algorithm of this TotpDeviceDto.  # noqa: E501


        :return: The algorithm of this TotpDeviceDto.  # noqa: E501
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """Sets the algorithm of this TotpDeviceDto.


        :param algorithm: The algorithm of this TotpDeviceDto.  # noqa: E501
        :type: str
        """

        self._algorithm = algorithm

    @property
    def created_at(self):
        """Gets the created_at of this TotpDeviceDto.  # noqa: E501


        :return: The created_at of this TotpDeviceDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this TotpDeviceDto.


        :param created_at: The created_at of this TotpDeviceDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this TotpDeviceDto.  # noqa: E501


        :return: The updated_at of this TotpDeviceDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this TotpDeviceDto.


        :param updated_at: The updated_at of this TotpDeviceDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TotpDeviceDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TotpDeviceDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class UpdateDevicePreviewFeedbackOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'str',
        'rating': 'int',
        'title': 'str',
        'comment': 'str',
        'internal_note': 'str',
        'append_internal_note': 'bool',
        'session_id': 'str',
        'live_view_url': 'str',
        'metadata': 'dict(str, str)'
    }

    attribute_map = {
        'status': 'status',
        'rating': 'rating',
        'title': 'title',
        'comment': 'comment',
        'internal_note': 'internalNote',
        'append_internal_note': 'appendInternalNote',
        'session_id': 'sessionId',
        'live_view_url': 'liveViewUrl',
        'metadata': 'metadata'
    }

    def __init__(self, status=None, rating=None, title=None, comment=None, internal_note=None, append_internal_note=None, session_id=None, live_view_url=None, metadata=None, local_vars_configuration=None):  # noqa: E501
        """UpdateDevicePreviewFeedbackOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._rating = None
        self._title = None
        self._comment = None
        self._internal_note = None
        self._append_internal_note = None
        self._session_id = None
        self._live_view_url = None
        self._metadata = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if rating is not None:
            self.rating = rating
        if title is not None:
            self.title = title
        if comment is not None:
            self.comment = comment
        if internal_note is not None:
            self.internal_note = internal_note
        if append_internal_note is not None:
            self.append_internal_note = append_internal_note
        if session_id is not None:
            self.session_id = session_id
        if live_view_url is not None:
            self.live_view_url = live_view_url
        if metadata is not None:
            self.metadata = metadata

    @property
    def status(self):
        """Gets the status of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The status of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UpdateDevicePreviewFeedbackOptions.


        :param status: The status of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["OPEN", "ACKNOWLEDGED", "RESOLVED", "DISMISSED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def rating(self):
        """Gets the rating of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The rating of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: int
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """Sets the rating of this UpdateDevicePreviewFeedbackOptions.


        :param rating: The rating of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: int
        """

        self._rating = rating

    @property
    def title(self):
        """Gets the title of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The title of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this UpdateDevicePreviewFeedbackOptions.


        :param title: The title of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def comment(self):
        """Gets the comment of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The comment of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this UpdateDevicePreviewFeedbackOptions.


        :param comment: The comment of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def internal_note(self):
        """Gets the internal_note of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The internal_note of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._internal_note

    @internal_note.setter
    def internal_note(self, internal_note):
        """Sets the internal_note of this UpdateDevicePreviewFeedbackOptions.


        :param internal_note: The internal_note of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """

        self._internal_note = internal_note

    @property
    def append_internal_note(self):
        """Gets the append_internal_note of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The append_internal_note of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: bool
        """
        return self._append_internal_note

    @append_internal_note.setter
    def append_internal_note(self, append_internal_note):
        """Sets the append_internal_note of this UpdateDevicePreviewFeedbackOptions.


        :param append_internal_note: The append_internal_note of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: bool
        """

        self._append_internal_note = append_internal_note

    @property
    def session_id(self):
        """Gets the session_id of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The session_id of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """Sets the session_id of this UpdateDevicePreviewFeedbackOptions.


        :param session_id: The session_id of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """

        self._session_id = session_id

    @property
    def live_view_url(self):
        """Gets the live_view_url of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The live_view_url of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._live_view_url

    @live_view_url.setter
    def live_view_url(self, live_view_url):
        """Sets the live_view_url of this UpdateDevicePreviewFeedbackOptions.


        :param live_view_url: The live_view_url of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """

        self._live_view_url = live_view_url

    @property
    def metadata(self):
        """Gets the metadata of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The metadata of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this UpdateDevicePreviewFeedbackOptions.


        :param metadata: The metadata of this UpdateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: dict(str, str)
        """

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateDevicePreviewFeedbackOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateDevicePreviewFeedbackOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mailslurp_client.api_client import ApiClient
from mailslurp_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DevicePreviewsControllerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cancel_device_preview_run(self, run_id, **kwargs):  # noqa: E501
        """Cancel a running device preview run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_device_preview_run(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param CancelDevicePreviewRunOptions cancel_device_preview_run_options:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CancelDevicePreviewRunResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.cancel_device_preview_run_with_http_info(run_id, **kwargs)  # noqa: E501

    def cancel_device_preview_run_with_http_info(self, run_id, **kwargs):  # noqa: E501
        """Cancel a running device preview run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_device_preview_run_with_http_info(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param CancelDevicePreviewRunOptions cancel_device_preview_run_options:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CancelDevicePreviewRunResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'run_id',
            'cancel_device_preview_run_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_device_preview_run" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['run_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `run_id` when calling `cancel_device_preview_run`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'run_id' in local_var_params:
            path_params['runId'] = local_var_params['run_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'cancel_device_preview_run_options' in local_var_params:
            body_params = local_var_params['cancel_device_preview_run_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/device-previews/{runId}/cancel', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CancelDevicePreviewRunResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_device_preview_feedback(self, create_device_preview_feedback_options, **kwargs):  # noqa: E501
        """Create device preview feedback  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_device_preview_feedback(create_device_preview_feedback_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateDevicePreviewFeedbackOptions create_device_preview_feedback_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DevicePreviewFeedbackDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_device_preview_feedback_with_http_info(create_device_preview_feedback_options, **kwargs)  # noqa: E501

    def create_device_preview_feedback_with_http_info(self, create_device_preview_feedback_options, **kwargs):  # noqa: E501
        """Create device preview feedback  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_device_preview_feedback_with_http_info(create_device_preview_feedback_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateDevicePreviewFeedbackOptions create_device_preview_feedback_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DevicePreviewFeedbackDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'create_device_preview_feedback_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_device_preview_feedback" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'create_device_preview_feedback_options' is set
        if self.api_client.client_side_validation and ('create_device_preview_feedback_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['create_device_preview_feedback_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `create_device_preview_feedback_options` when calling `create_device_preview_feedback`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_device_preview_feedback_options' in local_var_params:
            body_params = local_var_params['create_device_preview_feedback_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/device-previews/feedback', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DevicePreviewFeedbackDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_device_preview_run(self, email_id, **kwargs):  # noqa: E501
        """Create a new device preview run for an email  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_device_preview_run(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: (required)
        :param CreateDevicePreviewOptions create_device_preview_options:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CreateDevicePreviewRunResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_device_preview_run_with_http_info(email_id, **kwargs)  # noqa: E501

    def create_device_preview_run_with_http_info(self, email_id, **kwargs):  # noqa: E501
        """Create a new device preview run for an email  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_device_preview_run_with_http_info(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: (required)
        :param CreateDevicePreviewOptions create_device_preview_options:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CreateDevicePreviewRunResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'email_id',
            'create_device_preview_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_device_preview_run" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'email_id' is set
        if self.api_client.client_side_validation and ('email_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['email_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `email_id` when calling `create_device_preview_run`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'email_id' in local_var_params:
            path_params['emailId'] = local_var_params['email_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_device_preview_options' in local_var_params:
            body_params = local_var_params['create_device_preview_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/{emailId}/device-previews', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateDevicePreviewRunResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_device_preview_run(self, run_id, **kwargs):  # noqa: E501
        """Delete local device preview run data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_device_preview_run(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeleteDevicePreviewRunResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_device_preview_run_with_http_info(run_id, **kwargs)  # noqa: E501

    def delete_device_preview_run_with_http_info(self, run_id, **kwargs):  # noqa: E501
        """Delete local device preview run data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_device_preview_run_with_http_info(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeleteDevicePreviewRunResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'run_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_device_preview_run" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['run_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `run_id` when calling `delete_device_preview_run`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'run_id' in local_var_params:
            path_params['runId'] = local_var_params['run_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/device-previews/{runId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteDevicePreviewRunResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def ensure_device_preview_run(self, email_id, **kwargs):  # noqa: E501
        """Return active run for email or create one when none exists  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ensure_device_preview_run(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: (required)
        :param CreateDevicePreviewOptions create_device_preview_options:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CreateDevicePreviewRunResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.ensure_device_preview_run_with_http_info(email_id, **kwargs)  # noqa: E501

    def ensure_device_preview_run_with_http_info(self, email_id, **kwargs):  # noqa: E501
        """Return active run for email or create one when none exists  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ensure_device_preview_run_with_http_info(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: (required)
        :param CreateDevicePreviewOptions create_device_preview_options:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CreateDevicePreviewRunResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'email_id',
            'create_device_preview_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ensure_device_preview_run" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'email_id' is set
        if self.api_client.client_side_validation and ('email_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['email_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `email_id` when calling `ensure_device_preview_run`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'email_id' in local_var_params:
            path_params['emailId'] = local_var_params['email_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_device_preview_options' in local_var_params:
            body_params = local_var_params['create_device_preview_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/{emailId}/device-previews/latest', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateDevicePreviewRunResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_device_preview_feedback(self, feedback_id, **kwargs):  # noqa: E501
        """Get a single device preview feedback item  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_feedback(feedback_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str feedback_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DevicePreviewFeedbackDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_device_preview_feedback_with_http_info(feedback_id, **kwargs)  # noqa: E501

    def get_device_preview_feedback_with_http_info(self, feedback_id, **kwargs):  # noqa: E501
        """Get a single device preview feedback item  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_feedback_with_http_info(feedback_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str feedback_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DevicePreviewFeedbackDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'feedback_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_device_preview_feedback" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'feedback_id' is set
        if self.api_client.client_side_validation and ('feedback_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['feedback_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `feedback_id` when calling `get_device_preview_feedback`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'feedback_id' in local_var_params:
            path_params['feedbackId'] = local_var_params['feedback_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/device-previews/feedback/{feedbackId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DevicePreviewFeedbackDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_device_preview_feedback_items(self, **kwargs):  # noqa: E501
        """List device preview feedback  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_feedback_items(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int page:
        :param int size:
        :param str source:
        :param str run_id:
        :param str status:
        :param str provider:
        :param str category:
        :param str search:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DevicePreviewFeedbackListDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_device_preview_feedback_items_with_http_info(**kwargs)  # noqa: E501

    def get_device_preview_feedback_items_with_http_info(self, **kwargs):  # noqa: E501
        """List device preview feedback  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_feedback_items_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int page:
        :param int size:
        :param str source:
        :param str run_id:
        :param str status:
        :param str provider:
        :param str category:
        :param str search:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DevicePreviewFeedbackListDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'page',
            'size',
            'source',
            'run_id',
            'status',
            'provider',
            'category',
            'search'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_device_preview_feedback_items" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'source' in local_var_params and local_var_params['source'] is not None:  # noqa: E501
            query_params.append(('source', local_var_params['source']))  # noqa: E501
        if 'run_id' in local_var_params and local_var_params['run_id'] is not None:  # noqa: E501
            query_params.append(('runId', local_var_params['run_id']))  # noqa: E501
        if 'status' in local_var_params and local_var_params['status'] is not None:  # noqa: E501
            query_params.append(('status', local_var_params['status']))  # noqa: E501
        if 'provider' in local_var_params and local_var_params['provider'] is not None:  # noqa: E501
            query_params.append(('provider', local_var_params['provider']))  # noqa: E501
        if 'category' in local_var_params and local_var_params['category'] is not None:  # noqa: E501
            query_params.append(('category', local_var_params['category']))  # noqa: E501
        if 'search' in local_var_params and local_var_params['search'] is not None:  # noqa: E501
            query_params.append(('search', local_var_params['search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/device-previews/feedback', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DevicePreviewFeedbackListDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_device_preview_run(self, run_id, **kwargs):  # noqa: E501
        """Get device preview run status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_run(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DevicePreviewRunDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_device_preview_run_with_http_info(run_id, **kwargs)  # noqa: E501

    def get_device_preview_run_with_http_info(self, run_id, **kwargs):  # noqa: E501
        """Get device preview run status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_run_with_http_info(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DevicePreviewRunDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'run_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_device_preview_run" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['run_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `run_id` when calling `get_device_preview_run`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'run_id' in local_var_params:
            path_params['runId'] = local_var_params['run_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/device-previews/{runId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DevicePreviewRunDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_device_preview_run_provider_progress(self, run_id, provider, **kwargs):  # noqa: E501
        """Get provider-level progress for a device preview run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_run_provider_progress(run_id, provider, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param str provider: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DevicePreviewProviderProgressDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_device_preview_run_provider_progress_with_http_info(run_id, provider, **kwargs)  # noqa: E501

    def get_device_preview_run_provider_progress_with_http_info(self, run_id, provider, **kwargs):  # noqa: E501
        """Get provider-level progress for a device preview run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_run_provider_progress_with_http_info(run_id, provider, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param str provider: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DevicePreviewProviderProgressDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'run_id',
            'provider'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_device_preview_run_provider_progress" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['run_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `run_id` when calling `get_device_preview_run_provider_progress`")  # noqa: E501
        # verify the required parameter 'provider' is set
        if self.api_client.client_side_validation and ('provider' not in local_var_params or  # noqa: E501
                                                        local_var_params['provider'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `provider` when calling `get_device_preview_run_provider_progress`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'run_id' in local_var_params:
            path_params['runId'] = local_var_params['run_id']  # noqa: E501
        if 'provider' in local_var_params:
            path_params['provider'] = local_var_params['provider']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/device-previews/{runId}/providers/{provider}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DevicePreviewProviderProgressDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_device_preview_run_results(self, run_id, **kwargs):  # noqa: E501
        """Get device preview run results  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_run_results(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DevicePreviewRunResultsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_device_preview_run_results_with_http_info(run_id, **kwargs)  # noqa: E501

    def get_device_preview_run_results_with_http_info(self, run_id, **kwargs):  # noqa: E501
        """Get device preview run results  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_run_results_with_http_info(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DevicePreviewRunResultsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'run_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_device_preview_run_results" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['run_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `run_id` when calling `get_device_preview_run_results`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'run_id' in local_var_params:
            path_params['runId'] = local_var_params['run_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/device-previews/{runId}/results', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DevicePreviewRunResultsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_device_preview_run_screenshot(self, run_id, screenshot_id, **kwargs):  # noqa: E501
        """Get a seeded device preview screenshot image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_run_screenshot(run_id, screenshot_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param str screenshot_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_device_preview_run_screenshot_with_http_info(run_id, screenshot_id, **kwargs)  # noqa: E501

    def get_device_preview_run_screenshot_with_http_info(self, run_id, screenshot_id, **kwargs):  # noqa: E501
        """Get a seeded device preview screenshot image  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_run_screenshot_with_http_info(run_id, screenshot_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str run_id: (required)
        :param str screenshot_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'run_id',
            'screenshot_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_device_preview_run_screenshot" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['run_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `run_id` when calling `get_device_preview_run_screenshot`")  # noqa: E501
        # verify the required parameter 'screenshot_id' is set
        if self.api_client.client_side_validation and ('screenshot_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['screenshot_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `screenshot_id` when calling `get_device_preview_run_screenshot`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'run_id' in local_var_params:
            path_params['runId'] = local_var_params['run_id']  # noqa: E501
        if 'screenshot_id' in local_var_params:
            path_params['screenshotId'] = local_var_params['screenshot_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/device-previews/{runId}/screenshots/{screenshotId}/image', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_device_preview_runs(self, email_id, **kwargs):  # noqa: E501
        """List previous device preview runs for an email  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_runs(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: (required)
        :param int limit:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DevicePreviewRunDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_device_preview_runs_with_http_info(email_id, **kwargs)  # noqa: E501

    def get_device_preview_runs_with_http_info(self, email_id, **kwargs):  # noqa: E501
        """List previous device preview runs for an email  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_runs_with_http_info(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: (required)
        :param int limit:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DevicePreviewRunDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'email_id',
            'limit'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_device_preview_runs" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'email_id' is set
        if self.api_client.client_side_validation and ('email_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['email_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `email_id` when calling `get_device_preview_runs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'email_id' in local_var_params:
            path_params['emailId'] = local_var_params['email_id']  # noqa: E501

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/{emailId}/device-previews', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DevicePreviewRunDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_device_preview_runs_for_account(self, **kwargs):  # noqa: E501
        """List previous device preview runs for account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_runs_for_account(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DevicePreviewRunDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_device_preview_runs_for_account_with_http_info(**kwargs)  # noqa: E501

    def get_device_preview_runs_for_account_with_http_info(self, **kwargs):  # noqa: E501
        """List previous device preview runs for account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_runs_for_account_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DevicePreviewRunDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'limit'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_device_preview_runs_for_account" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/device-previews', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DevicePreviewRunDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_device_preview_runs_offset_paginated(self, email_id, **kwargs):  # noqa: E501
        """List previous device preview runs for an email in paginated form  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_runs_offset_paginated(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: (required)
        :param int page: Optional page index in list pagination
        :param int size: Optional page size for paginated result list.
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageDevicePreviewRunProjection
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_device_preview_runs_offset_paginated_with_http_info(email_id, **kwargs)  # noqa: E501

    def get_device_preview_runs_offset_paginated_with_http_info(self, email_id, **kwargs):  # noqa: E501
        """List previous device preview runs for an email in paginated form  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_device_preview_runs_offset_paginated_with_http_info(email_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id: (required)
        :param int page: Optional page index in list pagination
        :param int size: Optional page size for paginated result list.
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageDevicePreviewRunProjection, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'email_id',
            'page',
            'size',
            'sort'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_device_preview_runs_offset_paginated" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'email_id' is set
        if self.api_client.client_side_validation and ('email_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['email_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `email_id` when calling `get_device_preview_runs_offset_paginated`")  # noqa: E501

        if self.api_client.client_side_validation and 'size' in local_var_params and local_var_params['size'] > 100:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `size` when calling `get_device_preview_runs_offset_paginated`, must be a value less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'email_id' in local_var_params:
            path_params['emailId'] = local_var_params['email_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/{emailId}/device-previews/offset-paginated', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDevicePreviewRunProjection',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_device_preview_feedback(self, feedback_id, update_device_preview_feedback_options, **kwargs):  # noqa: E501
        """Update device preview feedback  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_device_preview_feedback(feedback_id, update_device_preview_feedback_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str feedback_id: (required)
        :param UpdateDevicePreviewFeedbackOptions update_device_preview_feedback_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DevicePreviewFeedbackDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_device_preview_feedback_with_http_info(feedback_id, update_device_preview_feedback_options, **kwargs)  # noqa: E501

    def update_device_preview_feedback_with_http_info(self, feedback_id, update_device_preview_feedback_options, **kwargs):  # noqa: E501
        """Update device preview feedback  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_device_preview_feedback_with_http_info(feedback_id, update_device_preview_feedback_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str feedback_id: (required)
        :param UpdateDevicePreviewFeedbackOptions update_device_preview_feedback_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DevicePreviewFeedbackDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'feedback_id',
            'update_device_preview_feedback_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_device_preview_feedback" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'feedback_id' is set
        if self.api_client.client_side_validation and ('feedback_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['feedback_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `feedback_id` when calling `update_device_preview_feedback`")  # noqa: E501
        # verify the required parameter 'update_device_preview_feedback_options' is set
        if self.api_client.client_side_validation and ('update_device_preview_feedback_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_device_preview_feedback_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_device_preview_feedback_options` when calling `update_device_preview_feedback`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'feedback_id' in local_var_params:
            path_params['feedbackId'] = local_var_params['feedback_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_device_preview_feedback_options' in local_var_params:
            body_params = local_var_params['update_device_preview_feedback_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/emails/device-previews/feedback/{feedbackId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DevicePreviewFeedbackDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
